@@ -23,6 +23,9 @@ if ( !canView('Events') ) {
   return;
 }
 
+require_once('includes/Event.php');
+require_once('includes/Filter.php');
+
 $eid = validInt($_REQUEST['eid']);
 $fid = !empty($_REQUEST['fid']) ? validInt($_REQUEST['fid']) : 1;
 
@@ -87,10 +90,14 @@ if ( isset($_REQUEST['replayMode']) )
 if ( isset($_COOKIE['replayMode']) && preg_match('#^[a-z]+$#', $_COOKIE['replayMode']) )
   $replayMode = validHtmlStr($_COOKIE['replayMode']);
 
-if ( ( ! $replayMode ) or ( ! $replayModes[$replayMode] ) ) {
+if ( ( !$replayMode ) or ( !$replayModes[$replayMode] ) ) {
   $replayMode = 'none';
 }
 
+$video_tag = false;
+if ( $Event->DefaultVideo() and ( $codec == 'MP4' or $codec == 'auto' ) ) {
+  $video_tag = true;
+}
 // videojs zoomrotate only when direct recording
 $Zoom = 1;
 $Rotation = 0;
@@ -112,90 +119,80 @@ if ( !isset($_REQUEST['filter']) ) {
   );
 }
 parseSort();
-parseFilter($_REQUEST['filter']);
-$filterQuery = $_REQUEST['filter']['query'];
+$filter = ZM\Filter::parse($_REQUEST['filter']);
+$filterQuery = $filter->querystring();
 
 $connkey = generateConnKey();
 
-$focusWindow = true;
-
-$popup = (isset($_REQUEST['popup']) && ($_REQUEST['popup'] == 1));
-
-xhtmlHeaders(__FILE__, translate('Event'));
+xhtmlHeaders(__FILE__, translate('Event').' '.$Event->Id());
 ?>
 <body>
   <div id="page">
-    <?php if ( !$popup ) echo getNavBarHTML() ?>
-    <div id="header">
+    <?php echo getNavBarHTML() ?>
 <?php 
 if ( !$Event->Id() ) {
-  echo 'Event was not found.';
-} else {
+  echo '<div class="error">Event was not found.</div>';
+}
+
+if ( $Event->Id() and !file_exists($Event->Path()) )
+  echo '<div class="error">Event was not found at '.$Event->Path().'.  It is unlikely that playback will be possible.</div>';
 ?>
-      <div id="dataBar">
-        <span id="dataId" title="<?php echo translate('Id') ?>"><?php echo $Event->Id() ?></span>
-        <span id="dataMonitor" title="<?php echo translate('Monitor') ?>"><?php echo $Monitor->Id().' '.validHtmlStr($Monitor->Name()) ?></span>
-        <span id="dataCause" title="<?php echo $Event->Notes()?validHtmlStr($Event->Notes()):translate('AttrCause') ?>"><?php echo validHtmlStr($Event->Cause()) ?></span>
-        <span id="dataTime" title="<?php echo translate('Time') ?>"><?php echo strftime(STRF_FMT_DATETIME_SHORT, strtotime($Event->StartTime())) ?></span>
-        <span id="dataDuration" title="<?php echo translate('Duration') ?>"><?php echo $Event->Length().'s' ?></span>
-        <span id="dataFrames" title="<?php echo translate('AttrFrames').'/'.translate('AttrAlarmFrames') ?>"><?php echo $Event->Frames() ?>/<?php echo $Event->AlarmFrames() ?></span>
-        <span id="dataScore" title="<?php echo translate('AttrTotalScore').'/'.translate('AttrAvgScore').'/'.translate('AttrMaxScore') ?>"><?php echo $Event->TotScore() ?>/<?php echo $Event->AvgScore() ?>/<?php echo $Event->MaxScore() ?></span>
-        <span id="Storage">
-<?php echo 
-  human_filesize($Event->DiskSpace(null)) . ' on ' . validHtmlStr($Event->Storage()->Name()).
-  ( $Event->SecondaryStorageId() ? ', '.validHtmlStr($Event->SecondaryStorage()->Name()) : '' )
-?></span>
-        <div id="closeWindow"><a href="#" onclick="<?php echo $popup ? 'window.close()' : 'window.history.back();return false;' ?>"><?php echo $popup ? translate('Close') : translate('Back') ?></a></div>
+
+<!-- BEGIN HEADER -->
+    <div class="d-flex flex-row justify-content-between px-3 py-1">
+      <div id="toolbar" >
+        <button id="backBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Back') ?>" disabled><i class="fa fa-arrow-left"></i></button>
+        <button id="refreshBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Refresh') ?>" ><i class="fa fa-refresh"></i></button>
+<?php if ( $Event->Id() ) { ?>
+        <button id="renameBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Rename') ?>" disabled><i class="fa fa-font"></i></button>
+        <button id="archiveBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Archive') ?>" disabled><i class="fa fa-archive"></i></button>
+        <button id="unarchiveBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Unarchive') ?>" disabled><i class="fa fa-file-archive-o"></i></button>
+        <button id="editBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Edit') ?>" disabled><i class="fa fa-pencil"></i></button>
+        <button id="exportBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Export') ?>"><i class="fa fa-external-link"></i></button>
+<?php
+  if ( $Event->DefaultVideo() ) {
+?>
+        <a class="btn btn-normal" href="<?php echo $Event->getStreamSrc(array('mode'=>'mp4'),'&amp;')?>" download><i class="fa fa-download"></i></a>
+<?php
+  } 
+?>
+        <button id="statsBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Stats') ?>" ><i class="fa fa-info"></i></button>
+        <button id="framesBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Frames') ?>" ><i class="fa fa-picture-o"></i></button>
+        <button id="deleteBtn" class="btn btn-danger" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Delete') ?>"><i class="fa fa-trash"></i></button>
+<?php } // end if Event->Id ?>
       </div>
-      <div id="menuBar1">
-        <div id="nameControl">
-          <input type="text" id="eventName" name="eventName" value="<?php echo validHtmlStr($Event->Name()) ?>" />
-          <button value="Rename" type="button" data-on-click="renameEvent"<?php if ( !canEdit('Events') ) { ?> disabled="disabled"<?php } ?>>
-<?php echo translate('Rename') ?></button>
-        </div>
-<?php
-if ( canEdit('Events') ) {
-?>
-        <div id="deleteEvent"><button type="button" data-on-click="deleteEvent" <?php echo $Event->can_delete() ? '' : ' disabled="disabled" title="'.$Event->cant_delete_reason().'"' ?>><?php echo translate('Delete') ?></button></div>
-        <div id="editEvent"><button type="button" data-on-click="editEvent"><?php echo translate('Edit') ?></button></div>
-        <div id="archiveEvent"<?php echo $Event->Archived() == 1 ? ' class="hidden"' : ''  ?>><button type="button" data-on-click="archiveEvent"><?php echo translate('Archive') ?></button></div>
-        <div id="unarchiveEvent"<?php echo $Event->Archived() == 0 ? ' class="hidden"' : '' ?>><button type="button" data-on-click="unarchiveEvent"><?php echo translate('Unarchive') ?></button></div>
-<?php
-} // end if can edit Events
-?>
-        <div id="framesEvent"><button type="button" data-on-click="showEventFrames"><?php echo translate('Frames') ?></button></div>
-        <div id="streamEvent" class="hidden"><button data-on-click="showStream"><?php echo translate('Stream') ?></button></div>
-        <div id="stillsEvent"><button type="button" data-on-click="showStills"><?php echo translate('Stills') ?></button></div>
-<?php
-  if ( $Event->DefaultVideo() ) { 
-?>
-        <div id="downloadEventFile"><a class="btn-primary" href="<?php echo $Event->getStreamSrc(array('mode'=>'mp4'),'&amp;')?>" download>Download MP4</a></div>
-<?php
-  } else {
-?>
-        <div id="videoEvent"><button type="button" data-on-click="videoEvent"><?php echo translate('Video') ?></button></div>
-<?php
-  } // end if Event->DefaultVideo
-?>
-        <div id="exportEvent"><button type="button" data-on-click="exportEvent"><?php echo translate('Export') ?></button></div>
+      
+      <h2><?php echo translate('Event').' '.$Event->Id() ?></h2>
+      
+      <div class="d-flex flex-row">
         <div id="replayControl">
           <label for="replayMode"><?php echo translate('Replay') ?></label>
-          <?php echo htmlSelect('replayMode', $replayModes, $replayMode, array('data-on-change'=>'changeReplayMode')); ?>
+          <?php echo htmlSelect('replayMode', $replayModes, $replayMode, array('data-on-change'=>'changeReplayMode','id'=>'replayMode')); ?>
         </div>
         <div id="scaleControl">
           <label for="scale"><?php echo translate('Scale') ?></label>
-          <?php echo htmlSelect('scale', $scales, $scale, array('data-on-change'=>'changeScale')); ?>
+          <?php echo htmlSelect('scale', $scales, $scale, array('data-on-change'=>'changeScale','id'=>'scale')); ?>
         </div>
         <div id="codecControl">
           <label for="codec"><?php echo translate('Codec') ?></label>
-          <?php echo htmlSelect('codec', $codecs, $codec, array('data-on-change'=>'changeCodec')); ?>
+          <?php echo htmlSelect('codec', $codecs, $codec, array('data-on-change'=>'changeCodec','id'=>'codec')); ?>
         </div>
       </div>
     </div>
-    <div id="content">
+<?php if ( $Event->Id() ) { ?>
+<!-- BEGIN VIDEO CONTENT ROW -->
+    <div id="content" class="d-flex flex-row justify-content-center">
+      <div class="">
+        <!-- VIDEO STATISTICS TABLE -->
+        <table id="eventStatsTable" class="table-sm table-borderless">
+          <!-- EVENT STATISTICS POPULATED BY JAVASCRIPT -->
+        </table>
+      </div>
+      <div class="">
       <div id="eventVideo">
+      <!-- VIDEO CONTENT -->
 <?php
-if ( ($codec == 'MP4' || $codec == 'auto' ) && $Event->DefaultVideo() ) {
+if ( $video_tag ) {
 ?>
         <div id="videoFeed">
           <video id="videoobj" class="video-js vjs-default-skin"
@@ -236,7 +233,9 @@ if ( (ZM_WEB_STREAM_METHOD == 'mpeg') && ZM_MPEG_LIVE_FORMAT ) {
           <div class="progressBox" id="progressBox" title="" style="width: 0%;"></div>
         </div><!--progressBar-->
       </div><!--imageFeed-->
-<?php } /*end if !DefaultVideo*/ ?>
+<?php
+} /*end if !DefaultVideo*/
+?>
         <p id="dvrControls">
           <button type="button" id="prevBtn" title="<?php echo translate('Prev') ?>" class="inactive" data-on-click-true="streamPrev">
           <i class="material-icons md-18">skip_previous</i>
@@ -278,45 +277,11 @@ echo htmlSelect('rate', $rates, intval($rate), array('id'=>'rateValue'));
           <span id="zoom"><?php echo translate('Zoom') ?>: <span id="zoomValue">1</span>x</span>
         </div>
       </div><!--eventVideo-->
-      <div id="eventStills" class="hidden">
-        <div id="eventThumbsPanel">
-          <div id="eventThumbs">
-          </div>
-        </div>
-        <div id="eventImagePanel">
-          <div id="eventImageFrame">
-            <img id="eventImage" src="graphics/transparent.png" alt=""/>
-            <div id="eventImageBar">
-              <div id="eventImageClose"><button type="button" data-on-click="hideEventImage"><?php echo translate('Close') ?></button></div>
-              <div id="eventImageStats" class="hidden"><button type="button" data-on-click="showFrameStats"><?php echo translate('Stats') ?></button></div>
-              <div id="eventImageData"><?php echo translate('Frame') ?> <span id="eventImageNo"></span></div>
-            </div>
-          </div>
-        </div>
-        <div id="eventImageNav">
-          <div id="thumbsSliderPanel">
-            <div id="alarmCue" class="alarmCue"></div>
-            <div id="thumbsSlider">
-              <div id="thumbsKnob">
-              </div>
-            </div>
-          </div>
-          <div id="eventImageButtons">
-            <div id="prevButtonsPanel">
-              <button id="prevEventBtn" type="button" data-on-click="prevEvent" disabled="disabled">&lt;E</button>
-              <button id="prevThumbsBtn" type="button" data-on-click="prevThumbs" disabled="disabled">&lt;&lt;</button>
-              <button id="prevImageBtn" type="button" data-on-click="prevImage" disabled="disabled">&lt;</button>
-              <button id="nextImageBtn" type="button" data-on-click="nextImage" disabled="disabled">&gt;</button>
-              <button id="nextThumbsBtn" type="button" data-on-click="nextThumbs" disabled="disabled">&gt;&gt;</button>
-              <button id="nextEventBtn" type="button" data-on-click="nextEvent" disabled="disabled">E&gt;</button>
-            </div>
-          </div>
-        </div>
-      </div>
 <?php
 } // end if Event exists
 ?>
+  </div>
     </div><!--content-->
+    
   </div><!--page-->
-</body>
-</html>
+<?php xhtmlFooter() ?>
