@@ -49,13 +49,6 @@ $heights = array(
   '1080' => '1080px',
 );
 
-$scale = '100';   # actual
-
-if ( isset($_REQUEST['scale']) ) {
-  $scale = validInt($_REQUEST['scale']);
-} else if ( isset($_COOKIE['zmMontageScale']) ) {
-  $scale = validInt($_COOKIE['zmMontageScale']);
-}
 
 $layouts = ZM\MontageLayout::find(NULL, array('order'=>"lower('Name')"));
 $layoutsById = array();
@@ -86,7 +79,7 @@ if ( $layout_id and is_numeric($layout_id) and isset($layoutsById[$layout_id]) )
   $Layout = $layoutsById[$layout_id];
   $Positions = json_decode($Layout->Positions(), true);
 } else {
-  ZM\Logger::Debug('Layout not found');
+  ZM\Debug('Layout not found');
 }
 if ( $Layout and ( $Layout->Name() != 'Freeform' ) ) {
   // Use layout instead of other options
@@ -96,8 +89,9 @@ if ( isset($_COOKIE['zmMontageWidth']) ) {
   $_SESSION['zmMontageWidth'] = $options['width'] = validInt($_COOKIE['zmMontageWidth']);
 #} elseif ( isset($_SESSION['zmMontageWidth']) and $_SESSION['zmMontageWidth'] ) {
   #$options['width'] = $_SESSION['zmMontageWidth'];
-} else
+} else {
   $options['width'] = 0;
+}
 
 if ( isset($_COOKIE['zmMontageHeight']) ) {
   $_SESSION['zmMontageHeight'] = $options['height'] = validInt($_COOKIE['zmMontageHeight']);
@@ -107,8 +101,14 @@ if ( isset($_COOKIE['zmMontageHeight']) ) {
   $options['height'] = 0;
 }
 
-#if ( $scale ) 
-  $options['scale'] = $scale;
+$scale = '100';   # actual
+
+if ( isset($_REQUEST['scale']) ) {
+  $scale = validInt($_REQUEST['scale']);
+} else if ( isset($_COOKIE['zmMontageScale']) ) {
+  $scale = validInt($_COOKIE['zmMontageScale']);
+}
+$options['scale'] = $scale;
 
 session_write_close();
 
@@ -118,7 +118,7 @@ $filterbar = ob_get_contents();
 ob_end_clean();
 
 $monitors = array();
-foreach( $displayMonitors as &$row ) {
+foreach ( $displayMonitors as &$row ) {
   if ( $row['Function'] == 'None' )
     continue;
 
@@ -127,7 +127,6 @@ foreach( $displayMonitors as &$row ) {
 
   if ( ZM_OPT_CONTROL && $row['ControlId'] && $row['Controllable'] )
     $showControl = true;
-  $row['connKey'] = generateConnKey();
   if ( ! isset($widths[$row['Width']]) ) {
     $widths[$row['Width']] = $row['Width'].'px';
   }
@@ -138,26 +137,33 @@ foreach( $displayMonitors as &$row ) {
 } # end foreach Monitor
 
 xhtmlHeaders(__FILE__, translate('Montage'));
+getBodyTopHTML();
+echo getNavBarHTML();
 ?>
-<body>
   <div id="page">
-    <?php echo getNavBarHTML() ?>
-    <div id="header">&nbsp;&nbsp;
-      <a href="#"><span id="hdrbutton" class="glyphicon glyphicon-menu-up pull-right" title="Toggle Filters"></span></a>
-      <div id="flipMontageHeader">
+    <div id="header">
+<?php
+    $html = '';
+    $flip = ( (!isset($_COOKIE['zmMonitorFilterBarFlip'])) or ($_COOKIE['zmMonitorFilterBarFlip'] == 'down')) ? 'up' : 'down';
+    $html .= '<a class="flip" href="#"><i id="mfbflip" class="material-icons md-18">keyboard_arrow_' .$flip. '</i></a>'.PHP_EOL;
+    $html .= '<div class="container-fluid" id="mfbpanel"'.( ( $flip == 'down' ) ? ' style="display:none;"' : '' ) .'>'.PHP_EOL;
+    echo $html;
+?>
         <div id="headerButtons">
 <?php
 if ( $showControl ) {
-  echo makePopupLink('?view=control', 'zmControl', 'control', translate('Control'));
+  echo makeLink('?view=control', translate('Control'));
 }
-if ( $showZones ) {
-?>
-        <a id="ShowZones" href="?view=montage&amp;showZones=0">Hide Zones</a>
-<?php
-} else {
-?>
-        <a id="ShowZones" href="?view=montage&amp;showZones=1">Show Zones</a>
-<?php
+if ( canView('System') ) {
+  if ( $showZones ) {
+  ?>
+    <a id="HideZones" href="?view=montage&amp;showZones=0"><?php echo translate('Hide Zones')?></a>
+  <?php
+  } else {
+  ?>
+    <a id="ShowZones" href="?view=montage&amp;showZones=1"><?php echo translate('Show Zones')?></a>
+  <?php
+  }
 }
 ?>
       </div>
@@ -166,25 +172,25 @@ if ( $showZones ) {
         <?php echo $filterbar ?>
       </form>
       <div id="sizeControl">
-        <form action="index.php?view=montage" method="post">
+        <form action="?view=montage" method="post">
           <input type="hidden" name="object" value="MontageLayout"/>
           <input type="hidden" name="action" value="Save"/>
 
           <span id="widthControl">
             <label><?php echo translate('Width') ?></label>
-            <?php echo htmlSelect('width', $widths, $options['width'], array('data-on-change-this'=>'changeSize')); ?>
+            <?php echo htmlSelect('width', $widths, $options['width'], array('id'=>'width', 'data-on-change-this'=>'changeSize')); ?>
           </span>
           <span id="heightControl">
             <label><?php echo translate('Height') ?></label>
-            <?php echo htmlSelect('height', $heights, $options['height'], array('data-on-change-this'=>'changeSize')); ?>
+            <?php echo htmlSelect('height', $heights, $options['height'], array('id'=>'height', 'data-on-change-this'=>'changeSize')); ?>
           </span>
           <span id="scaleControl">
             <label><?php echo translate('Scale') ?></label>
-            <?php echo htmlSelect('scale', $scales, $scale, array('data-on-change-this'=>'changeScale')); ?>
+            <?php echo htmlSelect('scale', $scales, $scale, array('id'=>'scale', 'data-on-change-this'=>'changeScale')); ?>
           </span> 
           <span id="layoutControl">
             <label for="layout"><?php echo translate('Layout') ?></label>
-            <?php echo htmlSelect('zmMontageLayout', $layoutsById, $layout_id, array('data-on-change'=>'selectLayout')); ?>
+            <?php echo htmlSelect('zmMontageLayout', $layoutsById, $layout_id, array('id'=>'zmMontageLayout', 'data-on-change'=>'selectLayout')); ?>
           </span>
           <input type="hidden" name="Positions"/>
           <button type="button" id="EditLayout" data-on-click-this="edit_layout"><?php echo translate('EditLayout') ?></button>
@@ -193,6 +199,13 @@ if ( $showZones ) {
             <button type="button" value="Save" data-on-click-this="save_layout"><?php echo translate('Save') ?></button>
             <button type="button" value="Cancel" data-on-click-this="cancel_layout"><?php echo translate('Cancel') ?></button>
           </span>
+
+<?php if (defined('ZM_FEATURES_SNAPSHOTS') and ZM_FEATURES_SNAPSHOTS) { ?>
+          <button type="button" name="snapshotBtn" data-on-click-this="takeSnapshot">
+            <i class="material-icons md-18">camera_enhance</i>
+            &nbsp;<?php echo translate('Snapshot') ?>
+          </button>
+<?php } ?>
         </form>
       </div>
     </div>
@@ -222,20 +235,7 @@ foreach ( $monitors as $monitor ) {
   $monitor_options['height'] = $monitor_options['height']?$monitor_options['height'].'px' : null;
   $monitor_options['connkey'] = $monitor->connKey();
 
-  ZM\Logger::Debug("Options: " . print_r($monitor_options,true));
-  if (0 and $Positions ) {
-    $monitor_options['width'] = '100%';
-    $monitor_options['height'] = '100%';
-    if ( 0 ) {
-    if ( isset($Positions[$monitor->Id()]) ) {
-      $monitor_options = array();
-      #$monitor_options = $Positions[$monitor->Id()];
-    } else if ( isset($Positions['default']) ) {
-      $monitor_options = array();
-      #$monitor_options = $Positions['default'];
-    }
-    }
-  }
+  #ZM\Warning('Options: ' . print_r($monitor_options,true));
 
   if ( $monitor->Type() == 'WebSite' ) {
     echo getWebSiteUrl(
@@ -288,7 +288,7 @@ foreach ( $monitors as $monitor ) {
 
 <svg class="zones" id="zones<?php echo $monitor->Id() ?>" style="position:absolute; top: 0; left: 0; background: none; width: 100%; height: 100%;" viewBox="0 0 <?php echo $monitor->ViewWidth() ?> <?php echo $monitor->ViewHeight() ?>" preserveAspectRatio="none">
 <?php
-foreach( array_reverse($zones) as $zone ) {
+foreach ( array_reverse($zones) as $zone ) {
   echo '<polygon points="'. $zone['AreaCoords'] .'" class="'. $zone['Type'].'" />';
 } // end foreach zone
 ?>
@@ -313,4 +313,5 @@ foreach( array_reverse($zones) as $zone ) {
       </div>
     </div>
   </div>
+  <script src="<?php echo cache_bust('js/MonitorStream.js') ?>"></script>
 <?php xhtmlFooter() ?>
